@@ -953,7 +953,7 @@ def svd(a, coerce_signs=True):
         # Short-and-fat case
         else:
             vt, s, ut = tsqr(a.T, compute_svd=True)
-            u, s, v = ut.T, s, vt.T
+            u, v = ut.T, vt.T
             truncate = a.shape[0] > a.shape[1]
         # Only when necessary, remove extra singular vectors if array
         # has shape that contradicts chunking, e.g. the array is a
@@ -994,7 +994,7 @@ def lu(a):
     xdim, ydim = a.shape
     if xdim != ydim:
         raise ValueError("Input must be a square matrix to perform lu decomposition")
-    if not len(set(a.chunks[0] + a.chunks[1])) == 1:
+    if len(set(a.chunks[0] + a.chunks[1])) != 1:
         msg = (
             "All chunks must be a square matrix to perform lu decomposition. "
             "Use .rechunk method to change the size of chunks."
@@ -1256,7 +1256,8 @@ def solve(a, b, sym_pos=None, assume_a="gen"):
         b = p.T.dot(b)
     else:
         raise ValueError(
-            f"{assume_a = } is not a recognized matrix structure, valid structures in Dask are 'pos' and 'gen'."
+            f"{assume_a = } is not a recognized matrix structure, "  # noqa: E251
+            "valid structures in Dask are 'pos' and 'gen'."
         )
 
     uy = solve_triangular(l, b, lower=True)
@@ -1325,7 +1326,7 @@ def _cholesky(a):
         raise ValueError(
             "Input must be a square matrix to perform cholesky decomposition"
         )
-    if not len(set(a.chunks[0] + a.chunks[1])) == 1:
+    if len(set(a.chunks[0] + a.chunks[1])) != 1:
         msg = (
             "All chunks must be a square matrix to perform cholesky decomposition. "
             "Use .rechunk method to change the size of chunks."
@@ -1482,11 +1483,10 @@ def norm(x, ord=None, axis=None, keepdims=False):
         if len(axis) == 1:
             raise ValueError("Invalid norm order for vectors.")
 
-    # Coerce to double precision.
-    r = x.astype(np.promote_types(x.dtype, float))
+    r = abs(x)
 
     if ord is None:
-        r = (abs(r) ** 2).sum(axis=axis, keepdims=keepdims) ** 0.5
+        r = (r**2).sum(axis=axis, keepdims=keepdims) ** 0.5
     elif ord == "nuc":
         if len(axis) == 1:
             raise ValueError("Invalid norm order for vectors.")
@@ -1495,7 +1495,6 @@ def norm(x, ord=None, axis=None, keepdims=False):
 
         r = svd(x)[1][None].sum(keepdims=keepdims)
     elif ord == np.inf:
-        r = abs(r)
         if len(axis) == 1:
             r = r.max(axis=axis, keepdims=keepdims)
         else:
@@ -1503,7 +1502,6 @@ def norm(x, ord=None, axis=None, keepdims=False):
             if keepdims is False:
                 r = r.squeeze(axis=axis)
     elif ord == -np.inf:
-        r = abs(r)
         if len(axis) == 1:
             r = r.min(axis=axis, keepdims=keepdims)
         else:
@@ -1516,7 +1514,6 @@ def norm(x, ord=None, axis=None, keepdims=False):
 
         r = (r != 0).astype(r.dtype).sum(axis=axis, keepdims=keepdims)
     elif ord == 1:
-        r = abs(r)
         if len(axis) == 1:
             r = r.sum(axis=axis, keepdims=keepdims)
         else:
@@ -1524,7 +1521,7 @@ def norm(x, ord=None, axis=None, keepdims=False):
             if keepdims is False:
                 r = r.squeeze(axis=axis)
     elif len(axis) == 2 and ord == -1:
-        r = abs(r).sum(axis=axis[0], keepdims=True).min(axis=axis[1], keepdims=True)
+        r = r.sum(axis=axis[0], keepdims=True).min(axis=axis[1], keepdims=True)
         if keepdims is False:
             r = r.squeeze(axis=axis)
     elif len(axis) == 2 and ord == 2:
@@ -1539,6 +1536,6 @@ def norm(x, ord=None, axis=None, keepdims=False):
         if len(axis) == 2:
             raise ValueError("Invalid norm order for matrices.")
 
-        r = (abs(r) ** ord).sum(axis=axis, keepdims=keepdims) ** (1.0 / ord)
+        r = (r**ord).sum(axis=axis, keepdims=keepdims) ** (1.0 / ord)
 
     return r
