@@ -1,15 +1,31 @@
+from __future__ import annotations
+
 import warnings
 
+from dask._compatibility import import_optional_dependency
+
+import_optional_dependency("numpy")
 import numpy as np
-from packaging.version import parse as parse_version
+from packaging.version import Version
 
 from dask.utils import derived_from
 
-_np_version = parse_version(np.__version__)
-_numpy_122 = _np_version >= parse_version("1.22.0")
-_numpy_123 = _np_version >= parse_version("1.23.0")
-_numpy_124 = _np_version >= parse_version("1.24.0")
-_numpy_125 = _np_version.release >= (1, 25, 0)
+_np_version = Version(np.__version__)
+NUMPY_GE_125 = _np_version.release >= (1, 25)
+NUMPY_GE_200 = _np_version.release >= (2, 0)
+NUMPY_GE_210 = _np_version.release >= (2, 1)
+
+
+if NUMPY_GE_200:
+    from numpy.exceptions import AxisError, ComplexWarning  # noqa: F401
+    from numpy.lib.array_utils import normalize_axis_index, normalize_axis_tuple
+else:
+    from numpy import (  # type: ignore[no-redef, attr-defined] # noqa: F401
+        AxisError,
+        ComplexWarning,
+    )
+    from numpy.core.numeric import normalize_axis_index  # type: ignore[no-redef]
+    from numpy.core.numeric import normalize_axis_tuple  # type: ignore[no-redef]
 
 
 # Taken from scikit-learn:
@@ -43,7 +59,7 @@ except TypeError:
             x = x.astype(dtype)
         return x
 
-    ma_divide = np.ma.core._DomainedBinaryOperation(  # type: ignore
+    ma_divide = np.ma.core._DomainedBinaryOperation(
         divide, np.ma.core._DomainSafeDivide(), 0, 1  # type: ignore
     )
 
@@ -133,10 +149,8 @@ class _Recurser:
 # https://github.com/numpy/numpy/blob/d9b1e32cb8ef90d6b4a47853241db2a28146a57d/numpy/core/numeric.py#L1336-L1405
 @derived_from(np)
 def moveaxis(a, source, destination):
-    source = np.core.numeric.normalize_axis_tuple(source, a.ndim, "source")
-    destination = np.core.numeric.normalize_axis_tuple(
-        destination, a.ndim, "destination"
-    )
+    source = normalize_axis_tuple(source, a.ndim, "source")
+    destination = normalize_axis_tuple(destination, a.ndim, "destination")
     if len(source) != len(destination):
         raise ValueError(
             "`source` and `destination` arguments must have "
@@ -156,7 +170,7 @@ def moveaxis(a, source, destination):
 # https://github.com/numpy/numpy/blob/v1.17.0/numpy/core/numeric.py#L1107-L1204
 def rollaxis(a, axis, start=0):
     n = a.ndim
-    axis = np.core.numeric.normalize_axis_index(axis, n)
+    axis = normalize_axis_index(axis, n)
     if start < 0:
         start += n
     msg = "'%s' arg requires %d <= %s < %d, but %d was passed in"
@@ -171,11 +185,3 @@ def rollaxis(a, axis, start=0):
     axes.remove(axis)
     axes.insert(start, axis)
     return a.transpose(axes)
-
-
-# kwarg is renamed in numpy 1.22.0
-def percentile(a, q, method="linear"):
-    if _numpy_122:
-        return np.percentile(a, q, method=method)
-    else:
-        return np.percentile(a, q, interpolation=method)
