@@ -2,9 +2,12 @@ from __future__ import annotations
 
 import os
 from collections.abc import Mapping
+from functools import partial
 from io import BytesIO
 from warnings import catch_warnings, simplefilter, warn
 
+from dask._task_spec import convert_legacy_task
+
 try:
     import psutil
 except ImportError:
@@ -25,136 +28,15 @@ from pandas.api.types import (
     is_object_dtype,
 )
 
-from dask.base import tokenize
+import dask.dataframe as dd
 from dask.bytes import read_bytes
 from dask.core import flatten
 from dask.dataframe.backends import dataframe_creation_dispatch
-from dask.dataframe.io.io import from_map
-from dask.dataframe.io.utils import DataFrameIOFunction
 from dask.dataframe.utils import clear_known_categories
 from dask.delayed import delayed
 from dask.utils import asciitable, parse_bytes
 
 
-class CSVFunctionWrapper(DataFrameIOFunction):
-    """
-    CSV Function-Wrapper Class
-    Reads CSV data from disk to produce a partition (given a key).
-    """
-
-    def __init__(
-        self,
-        full_columns,
-        columns,
-        colname,
-        head,
-        header,
-        reader,
-        dtypes,
-        enforce,
-        kwargs,
-    ):
-        self.full_columns = full_columns
-        self._columns = columns
-        self.colname = colname
-        self.head = head
-        self.header = header
-        self.reader = reader
-        self.dtypes = dtypes
-        self.enforce = enforce
-        self.kwargs = kwargs
-
-    @property
-    def columns(self):
-        if self._columns is None:
-            return self.full_columns
-        if self.colname:
-            return self._columns + [self.colname]
-        return self._columns
-
-    def project_columns(self, columns):
-        """Return a new CSVFunctionWrapper object with
-        a sub-column projection.
-        """
-        # Make sure columns is ordered correctly
-        columns = [c for c in self.head.columns if c in columns]
-        if columns == self.columns:
-            return self
-        if self.colname and self.colname not in columns:
-            # when path-as-column is on, we must keep it at IO
-            # whatever the selection
-            head = self.head[columns + [self.colname]]
-        else:
-            head = self.head[columns]
-        return CSVFunctionWrapper(
-            self.full_columns,
-            columns,
-            self.colname,
-            head,
-            self.header,
-            self.reader,
-            {c: self.dtypes[c] for c in columns},
-            self.enforce,
-            self.kwargs,
-        )
-
-    def __call__(self, part):
-        # Part will be a 3-element tuple
-        block, path, is_first, is_last = part
-
-        # Construct `path_info`
-        if path is not None:
-            path_info = (
-                self.colname,
-                path,
-                sorted(list(self.head[self.colname].cat.categories)),
-            )
-        else:
-            path_info = None
-
-        # Deal with arguments that are special
-        # for the first block of each file
-        write_header = False
-        rest_kwargs = self.kwargs.copy()
-        if not is_first:
-            if rest_kwargs.get("names", None) is None:
-                write_header = True
-            rest_kwargs.pop("skiprows", None)
-            if rest_kwargs.get("header", 0) is not None:
-                rest_kwargs.pop("header", None)
-        if not is_last:
-            rest_kwargs.pop("skipfooter", None)
-
-        # Deal with column projection
-        columns = self.full_columns
-        project_after_read = False
-        if self._columns is not None:
-            if self.kwargs:
-                # To be safe, if any kwargs are defined, avoid
-                # changing `usecols` here. Instead, we can just
-                # select columns after the read
-                project_after_read = True
-            else:
-                columns = self._columns
-                rest_kwargs["usecols"] = columns
-
-        # Call `pandas_read_text`
-        df = pandas_read_text(
-            self.reader,
-            block,
-            self.header,
-            rest_kwargs,
-            self.dtypes,
-            columns,
-            write_header,
-            self.enforce,
-            path_info,
-        )
-        if project_after_read:
-            return df[self.columns]
-        return df
-
-
 def pandas_read_text(
     reader,
     b,
@@ -368,7 +250,7 @@ def text_blocks_to_pandas(
 
     if path:
         colname, path_converter = path
-        paths = [b[1].path for b in blocks]
+        paths = [b.args[0].path for b in blocks]
         if path_converter:
             paths = [path_converter(p) for p in paths]
         head = head.assign(
@@ -386,31 +268,102 @@ def text_blocks_to_pandas(
     # Define parts
     parts = []
     colname, paths = path or (None, None)
-    for i in range(len(blocks)):
-        parts.append([blocks[i], paths[i] if paths else None, is_first[i], is_last[i]])
 
-    # Construct the output collection with from_map
-    return from_map(
-        CSVFunctionWrapper(
-            columns,
-            None,
-            colname,
-            head,
-            header,
-            reader,
-            dtypes,
-            enforce,
-            kwargs,
+    for i in range(len(blocks)):
+        parts.append([paths[i] if paths else None, is_first[i], is_last[i]])
+
+    return dd.from_map(
+        partial(
+            _read_csv,
+            full_columns=columns,
+            colname=colname,
+            head=head,
+            header=header,
+            reader=reader,
+            dtypes=dtypes,
+            enforce=enforce,
+            kwargs=kwargs,
+            blocksize=blocksize,
         ),
+        blocks,
         parts,
         meta=head,
         label="read-csv",
-        token=tokenize(reader, urlpath, columns, enforce, head, blocksize),
         enforce_metadata=False,
-        produces_tasks=True,
     )
 
 
+def _read_csv(
+    block,
+    part,
+    columns,
+    *,
+    reader,
+    header,
+    dtypes,
+    head,
+    colname,
+    full_columns,
+    enforce,
+    kwargs,
+    blocksize,
+):
+    # Part will be a 3-element tuple
+    path, is_first, is_last = part
+
+    # Construct `path_info`
+    if path is not None:
+        path_info = (
+            colname,
+            path,
+            sorted(head[colname].cat.categories),
+        )
+    else:
+        path_info = None
+
+    # Deal with arguments that are special
+    # for the first block of each file
+    write_header = False
+    rest_kwargs = kwargs.copy()
+    if not is_first:
+        if rest_kwargs.get("names", None) is None:
+            write_header = True
+        rest_kwargs.pop("skiprows", None)
+        if rest_kwargs.get("header", 0) is not None:
+            rest_kwargs.pop("header", None)
+    if not is_last:
+        rest_kwargs.pop("skipfooter", None)
+
+    # Deal with column projection
+    _columns = full_columns
+    project_after_read = False
+    if columns is not None and columns != full_columns:
+        if kwargs:
+            # To be safe, if any kwargs are defined, avoid
+            # changing `usecols` here. Instead, we can just
+            # select columns after the read
+            project_after_read = True
+        else:
+            _columns = columns
+            rest_kwargs["usecols"] = _columns
+
+    # Call `pandas_read_text`
+    df = pandas_read_text(
+        reader,
+        block,
+        header,
+        rest_kwargs,
+        dtypes,
+        _columns,
+        write_header,
+        enforce,
+        path_info,
+    )
+    if project_after_read:
+        return df[columns]
+    return df
+
+
 def block_mask(block_lists):
     """
     Yields a flat iterable of booleans to mark the zeroth elements of the
@@ -484,17 +437,28 @@ def read_pandas(
         kwargs["lineterminator"] = lineterminator
     else:
         lineterminator = "\n"
+    if "encoding" in kwargs:
+        b_lineterminator = lineterminator.encode(kwargs["encoding"])
+        empty_blob = "".encode(kwargs["encoding"])
+        if empty_blob:
+            # This encoding starts with a Byte Order Mark (BOM), so strip that from the
+            # start of the line terminator, since this value is not a full file.
+            b_lineterminator = b_lineterminator[len(empty_blob) :]
+    else:
+        b_lineterminator = lineterminator.encode()
     if include_path_column and isinstance(include_path_column, bool):
         include_path_column = "path"
-    if "index" in kwargs or "index_col" in kwargs:
+    if "index" in kwargs or (
+        "index_col" in kwargs and kwargs.get("index_col") is not False
+    ):
         raise ValueError(
-            "Keywords 'index' and 'index_col' not supported. "
-            f"Use dd.{reader_name}(...).set_index('my-index') instead"
+            "Keywords 'index' and 'index_col' not supported, except for "
+            "'index_col=False'. Use dd.{reader_name}(...).set_index('my-index') instead"
         )
     for kw in ["iterator", "chunksize"]:
         if kw in kwargs:
             raise ValueError(f"{kw} not supported for dd.{reader_name}")
-    if kwargs.get("nrows", None):
+    if kwargs.get("nrows"):
         raise ValueError(
             "The 'nrows' keyword is not supported by "
             "`dd.{0}`. To achieve the same behavior, it's "
@@ -521,7 +485,7 @@ def read_pandas(
         path_converter = None
 
     # If compression is "infer", inspect the (first) path suffix and
-    # set the proper compression option if the suffix is recongnized.
+    # set the proper compression option if the suffix is recognized.
     if compression == "infer":
         # Translate the input urlpath to a simple path list
         paths = get_fs_token_paths(urlpath, mode="rb", storage_options=storage_options)[
@@ -557,7 +521,6 @@ def read_pandas(
             "Setting ``sample=blocksize``"
         )
         sample = blocksize
-    b_lineterminator = lineterminator.encode()
     b_out = read_bytes(
         urlpath,
         delimiter=b_lineterminator,
@@ -585,8 +548,9 @@ def read_pandas(
     # Get header row, and check that sample is long enough. If the file
     # contains a header row, we need at least 2 nonempty rows + the number of
     # rows to skip.
-    names = kwargs.get("names", None)
+    names = kwargs.get("names")
     header = kwargs.get("header", "infer" if names is None else None)
+    kwargs["header"] = header
     need = 1 if header is None else 2
     if isinstance(header, int):
         firstrow += header
@@ -653,7 +617,13 @@ def read_pandas(
             if is_integer_dtype(head[c].dtype) and c not in specified_dtypes:
                 head[c] = head[c].astype(float)
 
-    values = [[list(dsk.dask.values()) for dsk in block] for block in values]
+    values = [
+        [
+            [convert_legacy_task(k, ts, {}) for k, ts in dsk.dask.items()]
+            for dsk in block
+        ]
+        for block in values
+    ]
 
     return text_blocks_to_pandas(
         reader,
@@ -922,6 +892,8 @@ def to_csv(
     --------
     fsspec.open_files
     """
+    df = df.optimize()
+
     if single_file and name_function is not None:
         raise ValueError("name_function is not supported under the single file mode")
     if header_first_partition_only is None:
@@ -941,7 +913,8 @@ def to_csv(
     if single_file:
         first_file = open_file(filename, mode=mode, **file_options)
         value = to_csv_chunk(dfs[0], first_file, **kwargs)
-        append_mode = mode.replace("w", "") + "a"
+        append_mode = mode if "a" in mode else mode + "a"
+        append_mode = append_mode.replace("w", "").replace("x", "")
         append_file = open_file(filename, mode=append_mode, **file_options)
         kwargs["header"] = False
         for d in dfs[1:]:
@@ -994,8 +967,3 @@ def to_csv(
         return list(dask.compute(*values, **compute_kwargs))
     else:
         return values
-
-
-from dask.dataframe.core import _Frame
-
-_Frame.to_csv.__doc__ = to_csv.__doc__
