@@ -1541,7 +1541,7 @@ class ArrowDatasetEngine(Engine):
                                     if isinstance(cmax, datetime)
                                     else cmax
                                 )
-                                last = cmax_last.get(name, None)
+                                last = cmax_last.get(name)
                                 if not (
                                     filters
                                     or (blocksize and split_row_groups is True)
@@ -1647,7 +1647,6 @@ class ArrowDatasetEngine(Engine):
             frag = None
 
             # Check if we have partitioning information.
-            # Not supported with fastparquet.
             partitioning = kwargs.get("dataset", {}).get("partitioning", None)
 
             # Check if we need to generate a fragment.
