@@ -7,6 +7,7 @@ import os
 import pickle
 import sys
 import traceback
+from collections.abc import Mapping, Sequence
 from concurrent.futures import ProcessPoolExecutor
 from functools import partial
 from warnings import warn
@@ -17,6 +18,7 @@ from dask import config
 from dask.local import MultiprocessingPoolExecutor, get_async, reraise
 from dask.optimization import cull, fuse
 from dask.system import CPU_COUNT
+from dask.typing import Key
 from dask.utils import ensure_dict
 
 
@@ -115,7 +117,7 @@ def pack_exception(e, dumps):
     tb = _pack_traceback(exc_traceback)
     try:
         result = dumps((e, tb))
-    except BaseException as e:
+    except Exception as e:
         exc_type, exc_value, exc_traceback = sys.exc_info()
         tb = _pack_traceback(exc_traceback)
         result = dumps((e, tb))
@@ -143,13 +145,14 @@ def get_context():
 
 
 def get(
-    dsk,
-    keys,
+    dsk: Mapping,
+    keys: Sequence[Key] | Key,
     num_workers=None,
     func_loads=None,
     func_dumps=None,
     optimize_graph=True,
     pool=None,
+    initializer=None,
     chunksize=None,
     **kwargs,
 ):
@@ -171,17 +174,21 @@ def get(
         If True [default], `fuse` is applied to the graph before computation.
     pool : Executor or Pool
         Some sort of `Executor` or `Pool` to use
+    initializer: function
+        Ignored if ``pool`` has been set.
+        Function to initialize a worker process before running any tasks in it.
     chunksize: int, optional
         Size of chunks to use when dispatching work.
-        Defaults to 5 as some batching is helpful.
+        Defaults to 6 as some batching is helpful.
         If -1, will be computed to evenly divide ready work across workers.
     """
     chunksize = chunksize or config.get("chunksize", 6)
     pool = pool or config.get("pool", None)
+    initializer = initializer or config.get("multiprocessing.initializer", None)
     num_workers = num_workers or config.get("num_workers", None) or CPU_COUNT
     if pool is None:
         # In order to get consistent hashing in subprocesses, we need to set a
-        # consistent seed for the Python hash algorithm. Unfortunatley, there
+        # consistent seed for the Python hash algorithm. Unfortunately, there
         # is no way to specify environment variables only for the Pool
         # processes, so we have to rely on environment variables being
         # inherited.
@@ -190,16 +197,25 @@ def get(
             # https://github.com/dask/dask/issues/6640.
             os.environ["PYTHONHASHSEED"] = "6640"
         context = get_context()
+        initializer = partial(initialize_worker_process, user_initializer=initializer)
         pool = ProcessPoolExecutor(
-            num_workers, mp_context=context, initializer=initialize_worker_process
+            num_workers, mp_context=context, initializer=initializer
         )
         cleanup = True
     else:
+        if initializer is not None:
+            warn(
+                "The ``initializer`` argument is ignored when ``pool`` is provided. "
+                "The user should configure ``pool`` with the needed ``initializer`` "
+                "on creation."
+            )
         if isinstance(pool, multiprocessing.pool.Pool):
             pool = MultiprocessingPoolExecutor(pool)
         cleanup = False
 
-    # Optimize Dask
+    if hasattr(dsk, "__dask_graph__"):
+        dsk = dsk.__dask_graph__()
+
     dsk = ensure_dict(dsk)
     dsk2, dependencies = cull(dsk, keys)
     if optimize_graph:
@@ -236,12 +252,19 @@ def get(
     return result
 
 
-def initialize_worker_process():
-    """
-    Initialize a worker process before running any tasks in it.
-    """
+def default_initializer():
     # If Numpy is already imported, presumably its random state was
     # inherited from the parent => re-seed it.
     np = sys.modules.get("numpy")
     if np is not None:
         np.random.seed()
+
+
+def initialize_worker_process(user_initializer=None):
+    """
+    Initialize a worker process before running any tasks in it.
+    """
+    default_initializer()
+
+    if user_initializer is not None:
+        user_initializer()
